==> owncloud-9.1.4.tgz: owncloud/apps/files/l10n/ko.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "저장소를 사용할 수 없음",
    "Storage invalid" : "저장소가 잘못됨",
    "Unknown error" : "알 수 없는 오류",
    "Unable to set upload directory." : "업로드 디렉터리를 설정할 수 없습니다.",
    "Invalid Token" : "잘못된 토큰",
    "No file was uploaded. Unknown error" : "파일이 업로드 되지 않았습니다. 알 수 없는 오류입니다",
    "There is no error, the file uploaded with success" : "파일 업로드에 성공했습니다.",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "업로드한 파일이 php.ini의 upload_max_filesize보다 큽니다:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "업로드한 파일 크기가 HTML 폼의 MAX_FILE_SIZE보다 큼",
    "The uploaded file was only partially uploaded" : "파일의 일부분만 업로드됨",
    "No file was uploaded" : "파일이 업로드되지 않았음",
    "Missing a temporary folder" : "임시 폴더가 없음",
    "Failed to write to disk" : "디스크에 쓰지 못했습니다",
    "Not enough storage available" : "저장소가 용량이 충분하지 않습니다.",
    "The target folder has been moved or deleted." : "대상 폴더가 이동되거나 삭제되었습니다.",
    "Upload failed. Could not find uploaded file" : "업로드에 실패했습니다. 업로드할 파일을 찾을 수 없습니다",
    "Upload failed. Could not get file info." : "업로드에 실패했습니다. 파일 정보를 가져올 수 없습니다.",
    "Invalid directory." : "올바르지 않은 디렉터리입니다.",
    "Files" : "파일",
    "All files" : "모든 파일",
    "Home" : "가정",
    "Close" : "닫기",
    "Favorites" : "즐겨찾기",
    "Upload cancelled." : "업로드가 취소되었습니다.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "{filename}을(를) 업로드할 수 없습니다. 폴더이거나 0 바이트 파일입니다.",
    "Total file size {size1} exceeds upload limit {size2}" : "총 파일 크기 {size1}이(가) 업로드 제한 {size2}을(를) 초과함",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "빈 공간이 부족합니다. 업로드할 파일 크기는 {size1}이지만 현재 {size2}만큼 비었습니다",
    "Error uploading file \"{fileName}\": {message}" : "\"{fileName}\"을(를) 업로드할 수 없음: {message}",
    "Could not get result from server." : "서버에서 결과를 가져올 수 없습니다.",
    "Uploading..." : "업로드 중...",
    "..." : "...",
    "File upload is in progress. Leaving the page now will cancel the upload." : "파일 업로드가 진행 중입니다. 이 페이지를 벗어나면 업로드가 취소됩니다.",
    "Actions" : "작업",
    "Download" : "다운로드",
    "Rename" : "이름 바꾸기",
    "Delete" : "삭제",
    "Disconnect storage" : "저장소 연결 해제",
    "Unshare" : "공유 해제",
    "Details" : "자세한 정보",
    "Select" : "선택",
    "Pending" : "대기 중",
    "Unable to determine date" : "날짜를 결정할 수 없음",
    "This operation is forbidden" : "이 작업이 금지됨",
    "This directory is unavailable, please check the logs or contact the administrator" : "디렉터리를 사용할 수 없습니다. 로그를 확인하거나 관리자에게 연락하십시오",
    "Could not move \"{file}\", target exists" : "\"{file}\"을(를) 이동할 수 없음, 대상이 존재함",
    "Could not move \"{file}\"" : "\"{file}\"을(를) 이동할 수 없음",
    "{newName} already exists" : "{newName}이(가) 이미 존재함",
    "Could not rename \"{fileName}\", it does not exist any more" : "\"{fileName}\"의 이름을 변경할 수 없음, 더 이상 존재하지 않음",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "\"{dir}\" 폴더 내에 \"{targetName}\" 파일이 이미 있습니다. 다른 이름을 사용하십시오.",
    "Could not rename \"{fileName}\"" : "\"{fileName}\"의 이름을 바꿀 수 없음",
    "Could not create file \"{file}\"" : "\"{file}\"을(를) 만들 수 없음",
    "Could not create file \"{file}\" because it already exists" : "파일이 이미 존재하므로 \"{file}\"을(를) 만들 수 없음",
    "Could not create folder \"{dir}\"" : "폴더 \"{dir}\"을(를) 만들 수 없음",
    "Could not create folder \"{dir}\" because it already exists" : "폴더가 이미 존재하므로 폴더 \"{dir}\"을(를) 만들 수 없음",
    "Error deleting file \"{fileName}\"." : "파일 \"{fileName}\"을(를) 삭제할 수 없습니다.",
    "No entries in this folder match '{filter}'" : "이 폴더에 '{filter}'와(과) 일치하는 항목 없음",
    "Name" : "이름",
    "Size" : "크기",
    "Modified" : "수정됨",
    "_%n folder_::_%n folders_" : ["폴더 %n개"],
    "_%n file_::_%n files_" : ["파일 %n개"],
    "{dirs} and {files}" : "{dirs} 그리고 {files}",
    "You don’t have permission to upload or create files here" : "여기에 파일을 업로드하거나 만들 권한이 없습니다",
    "_Uploading %n file_::_Uploading %n files_" : ["파일 %n개 업로드 중"],
    "New" : "새로 만들기",
    "\"{name}\" is an invalid file name." : "\"{name}\"은(는) 잘못된 파일 이름입니다.",
    "File name cannot be empty." : "파일 이름이 비어 있을 수 없습니다.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "{owner}의 저장소가 가득 찼습니다. 파일을 더 이상 업데이트하거나 동기화할 수 없습니다!",
    "Your storage is full, files can not be updated or synced anymore!" : "저장 공간이 가득 찼습니다. 파일을 업데이트하거나 동기화할 수 없습니다!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "{owner}의 저장 공간이 거의 가득 찼습니다({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "저장 공간이 거의 가득 찼습니다({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["'{filter}'와(과) 일치"],
    "Path" : "경로",
    "_%n byte_::_%n bytes_" : ["%n바이트"],
    "Favorited" : "책갈피에 추가됨",
    "Favorite" : "즐겨찾기",
    "Folder" : "폴더",
    "New folder" : "새 폴더",
    "{newname} already exists" : "{newname} 항목이 이미 존재함",
    "Upload" : "업로드",
    "An error occurred while trying to update the tags" : "태그를 업데이트하는 중 오류 발생",
    "A new file or folder has been <strong>created</strong>" : "새 파일이나 폴더가 <strong>생성됨</strong>",
    "A file or folder has been <strong>changed</strong>" : "파일이나 폴더가 <strong>변경됨</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "<strong>즐겨찾는 파일</strong>의 생성 및 변경 사항에 대한 알림을 줄일 수 있습니다<em>(스트림에서만)</em>",
    "A file or folder has been <strong>deleted</strong>" : "파일이나 폴더가 <strong>삭제됨</strong>",
    "A file or folder has been <strong>restored</strong>" : "파일이나 폴더가 <strong>복원됨</strong>",
    "You created %1$s" : "내가 %1$s을(를) 생성함",
    "%2$s created %1$s" : "%2$s 님이 %1$s을(를) 생성함",
    "%1$s was created in a public folder" : "공유 폴더에 %1$s 생성됨",
    "You changed %1$s" : "내가 %1$s을(를) 변경함",
    "%2$s changed %1$s" : "%2$s 님이 %1$s을(를) 변경함",
    "You deleted %1$s" : "내가 %1$s을(를) 삭제함",
    "%2$s deleted %1$s" : "%2$s 님이 %1$s을(를) 삭제함",
    "You restored %1$s" : "내가 %1$s을(를) 복원함",
    "%2$s restored %1$s" : "%2$s 님이 %1$s을(를) 복원함",
    "Changed by %2$s" : "%2$s 님이 변경함",
    "Deleted by %2$s" : "%2$s 님이 삭제함",
    "Restored by %2$s" : "%2$s 님이 복원함",
    "Upload (max. %s)" : "업로드(최대 %s)",
    "File handling" : "파일 처리",
    "Maximum upload size" : "최대 업로드 크기",
    "max. possible: " : "최대 가능:",
    "Save" : "저장",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "PHP-FPM을 사용 중이면 변경 사항이 적용되는 데 최대 5분 정도 걸릴 수 있습니다.",
    "Missing permissions to edit from here." : "여기에서 편집할 권한이 없습니다.",
    "Settings" : "설정",
    "WebDAV" : "WebDAV",
    "No files in here" : "여기에 파일 없음",
    "Upload some content or sync with your devices!" : "파일을 업로드하거나 장치와 동기화하십시오!",
    "No entries found in this folder" : "이 폴더에 항목 없음",
    "Select all" : "모두 선택",
    "Upload too large" : "업로드한 파일이 너무 큼",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "이 파일이 서버에서 허용하는 최대 업로드 가능 용량보다 큽니다.",
    "No favorites" : "책갈피 없음",
    "Files and folders you mark as favorite will show up here" : "책갈피에 추가한 파일과 폴더가 여기에 나타납니다",
    "Text file" : "텍스트 파일",
    "New text file.txt" : "새 텍스트 파일.txt"
},
"nplurals=1; plural=0;");

==> owncloud-10.0.7.tgz: owncloud/apps/files/l10n/ko.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "저장소를 임시로 사용할 수 없음",
    "Storage invalid" : "저장소가 잘못됨",
    "Unknown error" : "알 수 없는 오류",
    "All files" : "모든 파일",
    "Saved" : "저장됨",
    "There was an error saving" : "저장하는 중 오류가 발생",
    "File could not be found" : "파일을 찾을 수 없음",
    "Home" : "홈",
    "Close" : "닫기",
    "Favorites" : "즐겨찾기",
    "Could not create folder \"{dir}\"" : "폴더 \"{dir}\"을(를) 만들 수 없음",
    "Upload cancelled." : "업로드가 취소되었습니다.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "{filename}을(를) 업로드할 수 없습니다. 폴더이거나 0 바이트 파일입니다.",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "빈 공간이 부족합니다. 업로드할 파일 크기는 {size1}이지만 현재 {size2}만큼 비었습니다",
    "Target folder \"{dir}\" does not exist any more" : "대상 폴더 \"{dir}\"이(가) 더 이상 존재하지 않음",
    "Not enough free space" : "남은 공간이 부족함",
    "Uploading..." : "업로드 중...",
    "..." : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize}/{totalSize}({bitrate})",
    "File upload is in progress. Leaving the page now will cancel the upload." : "파일 업로드가 진행 중입니다. 이 페이지를 벗어나면 업로드가 취소됩니다.",
    "Actions" : "작업",
    "Download" : "다운로드",
    "Rename" : "이름 바꾸기",
    "Delete" : "삭제",
    "Disconnect storage" : "저장소 연결 해제",
    "Unshare" : "공유 해제",
    "Could not load info for file \"{file}\"" : "파일 \"{file}\"의 정보를 가져올 수 없음",
    "Files" : "파일",
    "Details" : "자세한 정보",
    "Select" : "선택",
    "Pending" : "대기 중",
    "Unable to determine date" : "날짜를 결정할 수 없음",
    "Invalid path" : "잘못된 경로",
    "This operation is forbidden" : "이 작업이 금지됨",
    "This directory is unavailable, please check the logs or contact the administrator" : "디렉터리를 사용할 수 없습니다. 로그를 확인하거나 관리자에게 연락하십시오",
    "Could not move \"{file}\", target exists" : "\"{file}\"을(를) 이동할 수 없음, 대상이 존재함",
    "Could not move \"{file}\"" : "\"{file}\"을(를) 이동할 수 없음",
    "{newName} already exists" : "{newName}이(가) 이미 존재함",
    "Could not rename \"{fileName}\", it does not exist any more" : "\"{fileName}\"의 이름을 변경할 수 없음, 더 이상 존재하지 않음",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "폴더 \"{dir}\" 내에 파일 \"{targetName}\"이(가) 이미 있습니다. 다른 이름을 사용하십시오.",
    "Could not rename \"{fileName}\"" : "\"{fileName}\"의 이름을 바꿀 수 없음",
    "Could not create file \"{file}\"" : "\"{file}\"을(를) 만들 수 없음",
    "Could not create file \"{file}\" because it already exists" : "파일이 이미 존재하므로 \"{file}\"을(를) 만들 수 없음",
    "Could not create folder \"{dir}\" because it already exists" : "폴더가 이미 존재하므로 폴더 \"{dir}\"을(를) 만들 수 없음",
    "Error deleting file \"{fileName}\"." : "파일 \"{fileName}\"을(를) 삭제할 수 없습니다.",
    "Name" : "이름",
    "Size" : "크기",
    "Modified" : "수정됨",
    "_%n folder_::_%n folders_" : ["폴더 %n개"],
    "_%n file_::_%n files_" : ["파일 %n개"],
    "{dirs} and {files}" : "{dirs} 그리고 {files}",
    "_including %n hidden_::_including %n hidden_" : ["숨김 항목 %n개 포함"],
    "You don’t have permission to upload or create files here" : "여기에 파일을 업로드하거나 만들 권한이 없습니다",
    "_Uploading %n file_::_Uploading %n files_" : ["파일 %n개 업로드 중"],
    "New" : "새로 만들기",
    "\"{name}\" is an invalid file name." : "\"{name}\"은(는) 잘못된 파일 이름입니다.",
    "File name cannot be empty." : "파일 이름이 비어 있을 수 없습니다.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "{owner}의 저장소가 가득 찼습니다. 파일을 더 이상 업데이트하거나 동기화할 수 없습니다!",
    "Your storage is full, files can not be updated or synced anymore!" : "저장 공간이 가득 찼습니다. 파일을 업데이트하거나 동기화할 수 없습니다!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "{owner}의 저장 공간이 거의 가득 찼습니다({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "저장 공간이 거의 가득 찼습니다({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["'{filter}'와(과) 일치"],
    "Path" : "경로",
    "_%n byte_::_%n bytes_" : ["%n 바이트"],
    "Favorited" : "즐겨찾기에 추가됨",
    "Favorite" : "즐겨찾기",
    "Private link:  Only people who have access to the file/folder can use it. Use it as a permanent link for yourself or to point others to files within shares" : "개인 링크: 파일이나 폴더에 접근할 수 있는 사람만 사용할 수 있습니다. 나 자신을 위한 고유 링크 및 다른 사람들에게 공유한 파일 주소를 알려 줄 때 사용할 수 있습니다",
    "Folder" : "폴더",
    "New folder" : "새 폴더",
    "{newname} already exists" : "{newname} 항목이 이미 존재함",
    "Upload" : "업로드",
    "An error occurred while trying to update the tags" : "태그를 업데이트하는 중 오류 발생",
    "A new file or folder has been <strong>created</strong>" : "새 파일이나 폴더가 <strong>생성됨</strong>",
    "A file or folder has been <strong>changed</strong>" : "파일이나 폴더가 <strong>변경됨</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "<strong>즐겨찾는 파일</strong>의 생성 및 변경 사항에 대한 알림을 줄일 수 있습니다<em>(스트림에서만)</em>",
    "A file or folder has been <strong>deleted</strong>" : "파일이나 폴더가 <strong>삭제됨</strong>",
    "A file or folder has been <strong>restored</strong>" : "파일이나 폴더가 <strong>복원됨</strong>",
    "You created %1$s" : "내가 %1$s을(를) 생성함",
    "%2$s created %1$s" : "%2$s 님이 %1$s을(를) 생성함",
    "%1$s was created in a public folder" : "공유 폴더에 %1$s 생성됨",
    "You changed %1$s" : "내가 %1$s을(를) 변경함",
    "%2$s changed %1$s" : "%2$s 님이 %1$s을(를) 변경함",
    "You deleted %1$s" : "내가 %1$s을(를) 삭제함",
    "%2$s deleted %1$s" : "%2$s 님이 %1$s을(를) 삭제함",
    "You restored %1$s" : "내가 %1$s을(를) 복원함",
    "%2$s restored %1$s" : "%2$s 님이 %1$s을(를) 복원함",
    "Changed by %2$s" : "%2$s 님이 변경함",
    "Deleted by %2$s" : "%2$s 님이 삭제함",
    "Restored by %2$s" : "%2$s 님이 복원함",
    "Upload (max. %s)" : "업로드(최대 %s)",
    "File handling" : "파일 처리",
    "Maximum upload size" : "최대 업로드 크기",
    "max. possible: " : "최대 가능:",
    "Save" : "저장",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "PHP-FPM을 사용 중이면 변경 사항이 적용되는 데 최대 5분 정도 걸릴 수 있습니다.",
    "Missing permissions to edit from here." : "여기에서 편집할 권한이 없습니다.",
    "Settings" : "설정",
    "Show hidden files" : "숨김 파일 보이기",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "<a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">내 파일에 WebDAV로 접근</a>하려면 이 주소를 사용하십시오",
    "No files in here" : "여기에 파일 없음",
    "Upload some content or sync with your devices!" : "파일을 업로드하거나 장치와 동기화하십시오!",
    "No entries found in this folder" : "이 폴더에 항목 없음",
    "Select all" : "모두 선택",
    "Upload too large" : "업로드한 파일이 너무 큼",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "이 파일이 서버에서 허용하는 최대 업로드 가능 용량보다 큽니다.",
    "No favorites" : "즐겨찾는 항목 없음",
    "Files and folders you mark as favorite will show up here" : "즐겨찾기에 추가한 파일과 폴더가 여기에 나타납니다",
    "Text file" : "텍스트 파일",
    "New text file.txt" : "새 텍스트 파일.txt"
},
"nplurals=1; plural=0;");
